@@ -19,6 +19,7 @@ module Statistics.Distribution.Gamma
       GammaDistribution
     -- * Constructors
     , gammaDistr
+    , improperGammaDistr
     -- * Accessors
     , gdShape
     , gdScale
@@ -27,8 +28,9 @@ module Statistics.Distribution.Gamma
 import Data.Typeable (Typeable)
 import Numeric.MathFunctions.Constants (m_pos_inf, m_NaN)
 import Numeric.SpecFunctions           (incompleteGamma, invIncompleteGamma)
-import Statistics.Distribution.Poisson.Internal as Poisson
-import qualified Statistics.Distribution        as D
+import Statistics.Distribution.Poisson.Internal  as Poisson
+import qualified Statistics.Distribution         as D
+import qualified System.Random.MWC.Distributions as MWC
 
 -- | The gamma distribution.
 data GammaDistribution = GD {
@@ -44,10 +46,18 @@ gammaDistr :: Double            -- ^ Shape parameter. /k/
 gammaDistr k theta
   | k     <= 0 = error $ msg ++ "shape must be positive. Got " ++ show k
   | theta <= 0 = error $ msg ++ "scale must be positive. Got " ++ show theta
-  | otherwise  = GD k theta
+  | otherwise  = improperGammaDistr k theta
     where msg = "Statistics.Distribution.Gamma.gammaDistr: "
 {-# INLINE gammaDistr #-}
 
+-- | Create gamma distribution. This constructor do not check whether
+--   parameters are valid
+improperGammaDistr :: Double            -- ^ Shape parameter. /k/
+                   -> Double            -- ^ Scale parameter, &#977;.
+                   -> GammaDistribution
+improperGammaDistr = GD
+{-# INLINE improperGammaDistr #-}
+
 instance D.Distribution GammaDistribution where
     cumulative = cumulative
 
@@ -70,6 +80,8 @@ instance D.MaybeVariance GammaDistribution where
     maybeStdDev   = Just . D.stdDev
     maybeVariance = Just . D.variance
 
+instance D.ContGen GammaDistribution where
+    genContVar (GD a l) = MWC.gamma a l
 
 
 density :: GammaDistribution -> Double -> Double
