@@ -25,7 +25,7 @@ import Data.Vector.Algorithms.Intro (sort)
 import Data.Vector.Generic (unsafeFreeze)
 import Data.Word (Word32)
 import GHC.Conc (numCapabilities)
-import Statistics.Function (create, indices)
+import Statistics.Function (indices)
 import Statistics.Types (Estimator, Sample)
 import System.Random.MWC (Gen, initialize, uniform, uniformVector)
 import qualified Data.Vector.Unboxed as U
@@ -61,14 +61,14 @@ resample gen ests numResamples samples = do
             zipWith (+) (replicate numCapabilities q)
                         (replicate r 1 ++ repeat 0)
           where (q,r) = numResamples `quotRem` numCapabilities
-  results <- mapM (const (MU.new numResamples)) $ ests
+  results <- mapM (const (MU.new numResamples)) ests
   done <- newChan
   forM_ (zip ixs (tail ixs)) $ \ (start,!end) -> do
     gen' <- initialize =<< (uniformVector gen 256 :: IO (U.Vector Word32))
     forkIO $ do
       let loop k ers | k >= end = writeChan done ()
                      | otherwise = do
-            re <- create numSamples $ \_ -> do
+            re <- U.replicateM numSamples $ do
                     r <- uniform gen'
                     return (U.unsafeIndex samples (r `mod` numSamples))
             forM_ ers $ \(est,arr) ->
