@@ -20,11 +20,9 @@ module Statistics.Resampling.Bootstrap
     -- $references
     ) where
 
-import Control.Applicative ((<$>), (<*>), empty)
 import Control.DeepSeq (NFData)
 import Control.Exception (assert)
 import Control.Monad.Par (runPar, parMap)
-import Data.Aeson.Types
 import Data.Data (Data)
 import Data.Typeable (Typeable)
 import Data.Vector.Unboxed ((!))
@@ -51,22 +49,6 @@ data Estimate = Estimate {
 
 instance NFData Estimate
 
-instance ToJSON Estimate where
-    toJSON Estimate{..} = object [
-                            "estPoint" .= estPoint
-                          , "estLowerBound" .= estLowerBound
-                          , "estUpperBound" .= estUpperBound
-                          , "estConfidenceLevel" .= estConfidenceLevel
-                          ]
-
-instance FromJSON Estimate where
-    parseJSON (Object v) = Estimate <$>
-                           v .: "estPoint" <*>
-                           v .: "estLowerBound" <*>
-                           v .: "estUpperBound" <*>
-                           v .: "estConfidenceLevel"
-    parseJSON _ = empty
-
 -- | Multiply the point, lower bound, and upper bound in an 'Estimate'
 -- by the given value.
 scale :: Double                 -- ^ Value to multiply by.
