@@ -47,13 +47,13 @@ module Statistics.Sample.Powers
     -- $references
     ) where
 
-import Data.Vector.Generic (unsafeFreeze)
-import Data.Vector.Unboxed ((!))
+import Data.Vector.Generic   (unsafeFreeze)
+import Data.Vector.Unboxed   ((!))
 import Prelude hiding (sum)
-import Statistics.Function (indexed)
-import Statistics.Internal (inlinePerformIO)
-import Statistics.Math (choose)
-import System.IO.Unsafe (unsafePerformIO)
+import Statistics.Function   (indexed)
+import Statistics.Internal   (inlinePerformIO)
+import Numeric.SpecFunctions (choose)
+import System.IO.Unsafe      (unsafePerformIO)
 import qualified Data.Vector.Unboxed as U
 import qualified Data.Vector.Generic as G
 import qualified Data.Vector.Unboxed.Mutable as MU
